#ifndef XS_TEST_CONFIG_H_INCLUDED
#define XS_TEST_CONFIG_H_INCLUDED

#include <deque>
#include <memory>

#include <boost/filesystem.hpp>
#include <boost/range/iterator_range.hpp>
#include <nlohmann/json.hpp>

#include "test/Expectation.h"
#include "test/Service.h"


namespace xs { namespace test
{
    class Config final
    {
    private:
        using service_range_type     = std::deque<Service>;
        using expectation_range_type = std::deque<Expectation>;

    public:
        Config() = delete;
        explicit Config(const boost::filesystem::path& file);
        Config(const Config&) = delete;
        Config(Config&&) = delete;
        ~Config() noexcept = default;

        Config& operator=(const Config&) = delete;
        Config& operator=(Config&&) = delete;

        boost::iterator_range<
            service_range_type::const_iterator
        > getServices() const noexcept;

        boost::iterator_range<
            expectation_range_type::const_iterator
        > getExpectations() const noexcept;

    private:
        static bool verify(const nlohmann::json& object) noexcept;

    private:
        service_range_type     services_;
        expectation_range_type expectations_;
    };
} }

#endif
